@@ -88,6 +88,83 @@ def test_package_dag_filter_packages_uses_pep503normalize(
     assert len(pkgs) == 0
 
 
+@pytest.mark.parametrize(
+    ("graph", "exclude", "expected"),
+    [
+        pytest.param(
+            {
+                ("a", "1.0.0"): [("b", []), ("c", []), ("d", []), ("e", [])],
+                ("b", "2.0.0"): [("x", []), ("y", []), ("z", [])],
+                ("c", "3.0.0"): [("d", [])],
+                ("d", "4.0.0"): [],
+                ("e", "5.0.0"): [("y", [])],
+                ("f", "6.0.0"): [("d", [])],  # Make sure that "d" is not removed since "f" is not excluded
+                ("g", "7.0.0"): [],
+                ("x", "8.0.0"): [],
+                ("y", "9.0.0"): [],
+                ("z", "10.0.0"): [],
+            },
+            {"a"},
+            {"d", "f", "g"},
+            id="with-dependencies",
+        ),
+        pytest.param(
+            {
+                ("acorn", "1.0.0"): [("b", []), ("c", []), ("d", []), ("e", [])],
+                ("b", "2.0.0"): [("x", []), ("y", []), ("z", [])],
+                ("c", "3.0.0"): [("d", [])],
+                ("d", "4.0.0"): [],
+                ("e", "5.0.0"): [("y", [])],
+                ("f", "6.0.0"): [("d", [])],
+                ("g", "7.0.0"): [],
+                ("x", "8.0.0"): [],
+                ("y", "9.0.0"): [],
+                ("z", "10.0.0"): [],
+            },
+            {"a*", "g"},
+            {"d", "f"},
+            id="with-multiple-excludes-and-with-patterns",
+        ),
+        pytest.param(
+            {
+                ("b", "2.0.0"): [("x", []), ("y", []), ("z", [])],
+                ("x", "8.0.0"): [],
+                ("y", "9.0.0"): [],
+                ("z", "10.0.0"): [],
+            },
+            {"dontexist"},
+            {"b", "x", "y", "z"},
+            id="with-non-existent-exclude",
+        ),
+        pytest.param(
+            {
+                ("a", "1.0.0"): [("b", [])],
+                ("b", "2.0.0"): [("c", [])],
+                ("c", "3.0.0"): [("d", [])],
+                ("d", "4.0.0"): [("e", [])],
+                ("e", "5.0.0"): [("f", [])],
+                ("f", "6.0.0"): [("g", [])],
+                ("g", "7.0.0"): [("x", [])],
+                ("x", "8.0.0"): [("y", [])],
+                ("y", "9.0.0"): [("z", [])],
+                ("z", "10.0.0"): [],
+            },
+            {"c"},
+            {"a", "b"},
+            id="with-package-having-large-depth",
+        ),
+    ],
+)
+def test_package_dag_filter_packages_given_exclude_dependencies(
+    mock_pkgs: Callable[[MockGraph], Iterator[Mock]], graph: MockGraph, exclude: set[str], expected: list[str]
+) -> None:
+    pkgs = PackageDAG.from_pkgs(list(mock_pkgs(graph)))
+    pkgs = pkgs.filter_nodes(None, exclude, exclude_deps=True)
+
+    assert len(pkgs) == len(expected)
+    assert all(p.key in expected for p in pkgs)
+
+
 def test_package_dag_reverse(example_dag: PackageDAG) -> None:
     def sort_map_values(m: dict[str, Any]) -> dict[str, Any]:
         return {k: sorted(v) for k, v in m.items()}
