@@ -37,6 +37,10 @@ def test_grahpviz_routing(mocker: MockerFixture) -> None:
 def test_text_routing(mocker: MockerFixture) -> None:
     render = mocker.patch("pipdeptree._render.render_text")
     main([])
-    render.assert_called_once_with(
-        ANY, encoding="utf-8", frozen=False, list_all=False, max_depth=inf, include_license=False
-    )
+    render.assert_called_once_with(ANY, encoding="utf-8", max_depth=inf, list_all=False, include_license=False)
+
+
+def test_freeze_routing(mocker: MockerFixture) -> None:
+    render = mocker.patch("pipdeptree._render.render_freeze")
+    main(["--freeze"])
+    render.assert_called_once_with(ANY, max_depth=inf, list_all=False)
